@@ -2,6 +2,9 @@
 
 use crate::{expr::*, types::*};
 
+#[cfg(feature = "backend-postgres")]
+pub use crate::extension::postgres::{PgFunc, PgFunction};
+
 /// Functions
 #[derive(Debug, Clone)]
 pub enum Function {
@@ -12,6 +15,8 @@ pub enum Function {
     Count,
     IfNull,
     CharLength,
+    #[cfg(feature = "backend-postgres")]
+    PgFunction(PgFunction),
     Custom(DynIden),
 }
 
