@@ -1,21 +1,28 @@
 //! Query statements (select, insert, update & delete).
-//! 
+//!
 //! # Usage
-//! 
+//!
 //! - Query Select, see [`SelectStatement`]
 //! - Query Insert, see [`InsertStatement`]
 //! - Query Update, see [`UpdateStatement`]
 //! - Query Delete, see [`DeleteStatement`]
 
-mod select;
-mod insert;
-mod update;
+mod condition;
 mod delete;
+mod insert;
+mod ordered;
+mod select;
+mod shim;
+mod traits;
+mod update;
 
-pub use select::*;
-pub use insert::*;
-pub use update::*;
+pub use condition::*;
 pub use delete::*;
+pub use insert::*;
+pub use ordered::*;
+pub use select::*;
+pub use traits::*;
+pub use update::*;
 
 /// Shorthand for constructing any table query
 #[derive(Debug, Clone)]
