@@ -2,7 +2,11 @@
 
 use crate::{expr::*, query::*};
 use std::fmt;
-pub use std::rc::Rc as SeaRc; // in case we some day we want to use Arc instead of Rc
+
+#[cfg(feature = "thread-safe")]
+pub use std::sync::Arc as SeaRc;
+#[cfg(not(feature = "thread-safe"))]
+pub use std::rc::Rc as SeaRc;
 
 /// Identifier in query
 pub trait Iden {
@@ -99,6 +103,12 @@ pub enum BinOper {
     Sub,
     Mul,
     Div,
+    #[cfg(feature = "backend-postgres")]
+    Matches,
+    #[cfg(feature = "backend-postgres")]
+    Contains,
+    #[cfg(feature = "backend-postgres")]
+    Contained,
 }
 
 /// Logical chain operator
@@ -142,6 +152,10 @@ pub enum Order {
 #[derive(Debug, Clone)]
 pub struct Alias(String);
 
+/// Null Alias
+#[derive(Debug, Copy, Clone)]
+pub struct NullAlias;
+
 /// Common SQL Keywords
 #[derive(Debug, Clone)]
 pub enum Keyword {
@@ -202,6 +216,12 @@ where
     }
 }
 
+impl IntoColumnRef for ColumnRef {
+    fn into_column_ref(self) -> ColumnRef {
+        self
+    }
+}
+
 impl<T: 'static> IntoColumnRef for T
 where
     T: IntoIden,
@@ -221,6 +241,12 @@ where
     }
 }
 
+impl IntoTableRef for TableRef {
+    fn into_table_ref(self) -> TableRef {
+        self
+    }
+}
+
 impl<T: 'static> IntoTableRef for T
 where
     T: IntoIden,
@@ -272,6 +298,16 @@ impl Iden for Alias {
     }
 }
 
+impl NullAlias {
+    pub fn new() -> Self {
+        Self
+    }
+}
+
+impl Iden for NullAlias {
+    fn unquoted(&self, _s: &mut dyn fmt::Write) {}
+}
+
 #[cfg(test)]
 mod tests {
     use crate::*;
@@ -282,14 +318,17 @@ mod tests {
             .column(Alias::new("hello-World_"))
             .to_owned();
 
+        #[cfg(feature = "backend-mysql")]
         assert_eq!(
             query.to_string(MysqlQueryBuilder),
             r#"SELECT `hello-World_`"#
         );
+        #[cfg(feature = "backend-postgres")]
         assert_eq!(
             query.to_string(PostgresQueryBuilder),
             r#"SELECT "hello-World_""#
         );
+        #[cfg(feature = "backend-sqlite")]
         assert_eq!(
             query.to_string(SqliteQueryBuilder),
             r#"SELECT `hello-World_`"#
@@ -300,11 +339,14 @@ mod tests {
     fn test_quoted_identifier_1() {
         let query = Query::select().column(Alias::new("hel`lo")).to_owned();
 
+        #[cfg(feature = "backend-mysql")]
         assert_eq!(query.to_string(MysqlQueryBuilder), r#"SELECT `hel``lo`"#);
+        #[cfg(feature = "backend-sqlite")]
         assert_eq!(query.to_string(SqliteQueryBuilder), r#"SELECT `hel``lo`"#);
 
         let query = Query::select().column(Alias::new("hel\"lo")).to_owned();
 
+        #[cfg(feature = "backend-postgres")]
         assert_eq!(query.to_string(PostgresQueryBuilder), r#"SELECT "hel""lo""#);
     }
 
@@ -312,11 +354,14 @@ mod tests {
     fn test_quoted_identifier_2() {
         let query = Query::select().column(Alias::new("hel``lo")).to_owned();
 
+        #[cfg(feature = "backend-mysql")]
         assert_eq!(query.to_string(MysqlQueryBuilder), r#"SELECT `hel````lo`"#);
+        #[cfg(feature = "backend-sqlite")]
         assert_eq!(query.to_string(SqliteQueryBuilder), r#"SELECT `hel````lo`"#);
 
         let query = Query::select().column(Alias::new("hel\"\"lo")).to_owned();
 
+        #[cfg(feature = "backend-postgres")]
         assert_eq!(
             query.to_string(PostgresQueryBuilder),
             r#"SELECT "hel""""lo""#
